﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Picture_Viewer
{
    public partial class ViewerForm : Form
    {
        const bool c_defPromptOnExit = false;
        string m_strUserName = "";
        bool m_blnPromptOnExit = c_defPromptOnExit;
        Color m_objPictureBackColor; 

        private void OpenPicture()
        {
            try
            {
                // Show the open file dialog box.
                if (ofdSelectPicture.ShowDialog() == DialogResult.OK)
                {
                    // Load the picture into the picture box.
                    picShowPicture.Image = Image.FromFile(ofdSelectPicture.FileName);
                    // Show the name of the file in the form’s caption.
                    this.Text = string.Concat("Picture Viewer(" +
                        ofdSelectPicture.FileName + ")");
                }
            }
            catch (System.OutOfMemoryException)
            {
                MessageBox.Show("The file you have chosen is not an image file.",
                    "Invalid File", MessageBoxButtons.OK);
            }
        }

        private void DrawBorder(PictureBox objPicturebox)
        {
            Graphics objGraphics = null;
            objGraphics = this.CreateGraphics();
            objGraphics.Clear(SystemColors.Control);
            objGraphics.DrawRectangle(Pens.Blue,
                  objPicturebox.Left - 1, objPicturebox.Top - 1,
                  objPicturebox.Width + 1, objPicturebox.Height + 1);
            objGraphics.Dispose();
        }

        public ViewerForm()
        {
            InitializeComponent();
        }

    

        private void btnEnlarge_Click(object sender, EventArgs e)
        {
            this.Width = this.Width + 20;
            this.Height = this.Height + 20;
        }

        private void btnShrink_Click(object sender, EventArgs e)
        {
            this.Width = this.Width - 20;
            this.Height = this.Height - 20;
        }

       

        private void picShowPicture_MouseMove(object sender, MouseEventArgs e)
        {
            lblX.Text = "X: " + e.X.ToString();
            lblY.Text = "Y: " + e.Y.ToString();

        }

        private void picShowPicture_MouseLeave(object sender, EventArgs e)
        {
            lblX.Text = "";
            lblY.Text = "";

        }

        private void ViewerForm_Load(object sender, EventArgs e)
        {
            lblX.Text = "";
            lblY.Text = "";

            m_blnPromptOnExit = c_defPromptOnExit;
            m_objPictureBackColor = System.Drawing.SystemColors.Control;

            picShowPicture.BackColor = m_objPictureBackColor;

            mnuConfirmOnExit.Checked = m_blnPromptOnExit;
        }

        private void mnuOpenPicture_Click(object sender, EventArgs e)
        {
            this.OpenPicture();
        }

        private void mnuConfirmOnExit_Click(object sender, EventArgs e)
        {
            mnuConfirmOnExit.Checked = !(mnuConfirmOnExit.Checked);
            
            m_blnPromptOnExit = mnuConfirmOnExit.Checked;
        }

        private void mnuQuit_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void mnuDrawBorder_Click(object sender, EventArgs e)
        {
            this.DrawBorder(picShowPicture);
        }

        private void mnuOptions_Click(object sender, EventArgs e)
        {
            OptionsForm frmOptionsDialog = new OptionsForm();
            frmOptionsDialog.ShowDialog();
        }

        private void drawBorderToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Graphics objGraphics = null;
            objGraphics = this.CreateGraphics();
            objGraphics.Clear(SystemColors.Control);
            objGraphics.DrawRectangle(Pens.Blue,
            picShowPicture.Left - 1, picShowPicture.Top - 1,
                  picShowPicture.Width + 1, picShowPicture.Height + 1);
            objGraphics.Dispose();

        }

        private void tbbOpenPicture_Click(object sender, EventArgs e)
        {
            this.OpenPicture();
        }

        private void tbbDrawBorder_Click(object sender, EventArgs e)
        {
            this.DrawBorder(picShowPicture);
        }

        private void tbbOptions_Click(object sender, EventArgs e)
        {
            OptionsForm frmOptionsDialog = new OptionsForm();
            frmOptionsDialog.ShowDialog();
        }

        private void mnuMainMenu_ItemClicked(object sender, ToolStripItemClickedEventArgs e)
        {

        }

        private void ViewerForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (m_blnPromptOnExit)
            {
                if (MessageBox.Show("Close the Picture Viewer program?", "Confirm Exit", 
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question)
                    == DialogResult.No)
                {
                    e.Cancel = true;
                }
            }

        }


    }
}
